@@ -563,7 +563,8 @@ sub _fetch_required_params {
 		set_website_rules  => { map { ($_ => 1) } qw(website_id exclude_rules) },
 		create_database    => { map { ($_ => 1) } qw(server_address account password port database_name) },
 		list_databases     => { },
-		show_database      => { map { ($_ => 1) } qw(website_id database_id) },
+		#show_database      => { map { ($_ => 1) } qw(website_id database_id) },
+        show_database      => { map { ($_ => 1) } qw(database_id) }, # Added in v0.03.
 		edit_database      => { map { ($_ => 1) } qw(database_id) },
 	};
 
@@ -601,6 +602,7 @@ sub _fetch_optional_params {
 		create_website  => { map { ($_ => 1) } qw(port dir_path) },
 		create_database => { map { ($_ => 1) } qw(website_id authentication_mode) },
 		edit_website    => { map { ($_ => 1) } qw(url monitor_frequency account password key dir_path hostname disabled) },
+        show_database   => { map { ($_ => 1) } qw(website_id) }, # Added in v0.03. 
 		edit_database   => { map { ($_ => 1) } qw(server_address account password port database_name authentication_mode server_account server_password website_id disabled) },
 	};
 	return $optional_keys_map->{$action};
